| owd | R Documentation |
owd opens the current working directory (or a given directory path) in your computer's file manager.
owd(dir = '.')
dir |
A character string indicating a directory path. Defaults to |
owd does not return any value in R. However, it will return an error if a directory path is passed to it that does not exist, or that R does not have sufficient privledges to access.
Tilde expansion (see path.expand) is performed on directory paths.
Benjamin G. Feakins, feakster@posteo.eu
getwd for the path of the current working directory.
list.files for the contents of a directory.
if (interactive()) {
## Open current working directory
owd()
## Open a directory using a relative path
owd('/usr/bin')
## Making use of tilde expansion to open the home directory
owd('~')
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.